# 0.9.0 (2020-04-24)

-   Refactored transliteration schemas into separate package. Nothing changed in external API.

# 0.8.0 (2020-04-23)

### Features

-   UN, scientific and library schemas ([d3f8462](https://github.com/nalgeon/iuliia-py/commit/d3f8462359e8c731d4b41cc92ff01bbf1ca6cfad))

# 0.7.0 (2020-04-22)

### Bug Fixes

-   mapping capitalization for different cases ([105d955](https://github.com/nalgeon/iuliia-py/commit/105d9551830c1149b14103c13ddc6ddb716289a3))

### Features

-   ICAO, ISO and telegram schemas ([26e3900](https://github.com/nalgeon/iuliia-py/commit/26e390068e86c86913a7a8a74d288613585f88fb))

# 0.6.0 (2020-04-21)

### Features

-   GOST and MVD schemas ([36688f7](https://github.com/nalgeon/iuliia-py/commit/36688f7f01858ee6f00bb7ef92a2e39da22b308f))

# 0.5.0 (2020-04-20)

### Features

-   command-line interface ([52fd29c](https://github.com/nalgeon/iuliia-py/commit/52fd29cc79219d2600aa709ab6d139318b2138c0))

# 0.4.0 (2020-04-20)

### Features

-   Wikipedia and Yandex.Maps schemas ([df7b5a3](https://github.com/nalgeon/iuliia-py/commit/df7b5a38030099d422c360d8e70f55e5cc98ebc1))

# 0.3.0 (2020-04-20)

### Features

-   Yandex.Money schema ([2430b32](https://github.com/nalgeon/iuliia-py/commit/2430b32b73f85bf1a7dc783180ad2479062fda7a))

# 0.2.1 (2020-04-20)

### Features

-   basic transliteration features ([72e5220](https://github.com/nalgeon/iuliia-py/commit/72e522093dc02172c84f9678be6904756a8d6ee3))
